@@ -1,10 +1,17 @@
 import pytest
-from qtpy import PYQT5, PYSIDE2
 
-@pytest.mark.skipif(not (PYQT5 or PYSIDE2), reason="Only available in Qt5 bindings")
+from qtpy import QT6
+from qtpy.tests.utils import using_conda
+
+
+@pytest.mark.skipif(
+    QT6 and using_conda(),
+    reason="QPositioning bindings not included in Conda qt-main >= 6.4.3.",
+)
 def test_qtpositioning():
     """Test the qtpy.QtPositioning namespace"""
     from qtpy import QtPositioning
+
     assert QtPositioning.QGeoAddress is not None
     assert QtPositioning.QGeoAreaMonitorInfo is not None
     assert QtPositioning.QGeoAreaMonitorSource is not None
